@@ -1,4 +1,4 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 import numpy as np
 import pandas as pd
 
@@ -8,12 +8,10 @@ from indsl.ts_utils.utility_functions import (
     normality_assumption_test,
     z_scores_test,
 )
-
-from ..type_check import check_types
-from ..validations import validate_series_has_time_index, validate_series_is_not_empty
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_time_index, validate_series_is_not_empty
 
 
-# todo add as indsl function
 @check_types
 def get_densities(data: pd.Series, time_window: pd.Timedelta = pd.Timedelta("5m")) -> pd.Series:
     """Point density.
@@ -28,7 +26,10 @@ def get_densities(data: pd.Series, time_window: pd.Timedelta = pd.Timedelta("5m"
     Returns:
         pd.Series: Time series with the point density for each rolling window.
     """
-    return data.rolling(time_window, min_periods=1).count()
+    # make sure index is in ns
+    index = data.index.astype("datetime64[ns]")
+    data_ns = pd.Series(data.values, index=index)
+    return data_ns.rolling(time_window, min_periods=1).count()
 
 
 @check_types
