@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2023 Cognite AS
 from typing import List
 
 import numpy as np
@@ -7,12 +7,11 @@ import pandas as pd
 from numpy.polynomial import polynomial
 from scipy.stats import t as student_dist
 
+from indsl.exceptions import UserValueError
 from indsl.resample.reindex import reindex
 from indsl.smooth import sg
-
-from ..exceptions import UserValueError
-from ..type_check import check_types
-from ..validations import validate_series_has_minimum_length
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_minimum_length
 
 
 @check_types
