@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2023 Cognite AS
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
@@ -37,7 +37,7 @@ class DataQualityScore:
             events: List of event events
                 Represented as pairs of timestamps
         """
-        for (event_start, event_end) in events:
+        for event_start, event_end in events:
             if event_start > event_end:
                 raise UserValueError(
                     f"Expected start date of event to be before end date, got event_start='{event_start}' and event_end='{event_end}'"
@@ -126,7 +126,7 @@ class DataQualityScoreAnalyser(ABC):
         self.series = series
 
     @abstractmethod
-    def compute_score(self, analysis_start: pd.Timestamp, analysis_end: pd.Timestamp) -> DataQualityScore:
+    def compute_score(self, analysis_start: pd.Timestamp, analysis_end: pd.Timestamp) -> DataQualityScore | None:
         """Compute data quality result.
 
         Args:
@@ -146,7 +146,7 @@ class DataQualityScoreAnalyser(ABC):
             )
 
         if len(self.series) < 1:
-            return  # type: ignore
+            return None
 
         if analysis_start < self.series.index[0]:
             raise UserValueError(
@@ -156,7 +156,7 @@ class DataQualityScoreAnalyser(ABC):
             raise UserValueError(
                 f"Expected analysis_end to be before or equal the last timestamp in series, got analysis_end={analysis_end} and series.index[-1]={self.series.index[-1]}"
             )
-        return  # type: ignore
+        return None
 
     def _convert_series_to_events(self, series) -> List[Tuple[pd.Timestamp, pd.Timestamp]]:
         # Each gap in the input series is represented as a consecutive (1, 1) pair.
@@ -170,7 +170,7 @@ class DataQualityScoreAnalyser(ABC):
         timestamps = np.array(self.series.index)
         events_array_unmerged = []
 
-        for (start, end) in events_array:
+        for start, end in events_array:
             merged_timestamps = timestamps[(timestamps > start) & (timestamps < end)]
             if merged_timestamps.size > 0:
                 events_unmerged = np.concatenate(
@@ -187,14 +187,12 @@ class DataQualityScoreAnalyser(ABC):
     def _filter_events_outside_analysis_period(
         events: List[Tuple[pd.Timestamp, pd.Timestamp]], analysis_start: pd.Timestamp, analysis_end: pd.Timestamp
     ) -> List[Tuple[pd.Timestamp, pd.Timestamp]]:
-
         return [(start, end) for start, end in events if end > analysis_start and start < analysis_end]
 
     @staticmethod
     def _limit_first_and_last_events_to_analysis_period(
         gaps: List[Tuple[pd.Timestamp, pd.Timestamp]], analysis_start: pd.Timestamp, analysis_end: pd.Timestamp
     ) -> List[Tuple[pd.Timestamp, pd.Timestamp]]:
-
         if len(gaps) == 0:
             return gaps
 
