@@ -1,16 +1,14 @@
-# Copyright 2022 Cognite AS
-from typing import Callable, List
+# Copyright 2023 Cognite AS
+from typing import List
 
 import numpy as np
 import pandas as pd
 
-from numba import jit
-
+from indsl.decorators import jit
 from indsl.detect.utils import resample_timeseries
-
-from ..exceptions import UserRuntimeError, UserTypeError, UserValueError
-from ..type_check import check_types
-from ..validations import validate_series_has_time_index
+from indsl.exceptions import UserRuntimeError, UserTypeError, UserValueError
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_time_index
 
 
 @check_types
@@ -34,7 +32,6 @@ def cpd_ed_pelt(data: pd.Series, min_distance: int = 1) -> pd.Series:
     validate_series_has_time_index(data)
 
     data_resampled: pd.Series = resample_timeseries(data=data)
-
     # the maximum allowable distance is half the number of datapoints
     max_distance: int = int(np.floor(len(data_resampled) / 2))
     if min_distance > max_distance:
@@ -49,7 +46,7 @@ def cpd_ed_pelt(data: pd.Series, min_distance: int = 1) -> pd.Series:
 
     # add the change points to the time series
     for cp in change_points:
-        change_points_ts[cp] = 1
+        change_points_ts.iloc[cp] = 1
         # add the value of 0 to 1ns before and after the timestamp of the current change point
         change_points_ts = pd.concat(
             [
@@ -193,7 +190,8 @@ def ed_pelt(data: np.ndarray, min_distance: int = 1) -> np.ndarray:
     # since we use the same values of `partial_sums`, `k`, `n` all the time,
     # we introduce a shortcut `cost(tau1, tau2)` for segment cost evaluation.
     # hereinafter, we use `tau` to name variables that are changepoint candidates.
-    cost: Callable[[int, int], float] = lambda tau1, tau2: get_segment_cost(partial_sums, tau1, tau2, k, n)
+    def cost(tau1: int, tau2: int) -> float:
+        return get_segment_cost(partial_sums, tau1, tau2, k, n)
 
     # we will use dynamic programming to find the best solution; `best_cost` is the cost array.
     # `best_cost[i]` is the cost for subarray `data[0..i - 1]`.
@@ -226,7 +224,7 @@ def ed_pelt(data: np.ndarray, min_distance: int = 1) -> np.ndarray:
         ]
 
         # Now we should choose the tau that provides the minimum possible cost.
-        best_previous_tau_index: int = np.argmin(cost_for_previous_tau)
+        best_previous_tau_index: np.int64 = np.argmin(cost_for_previous_tau).astype(np.int64)
         best_cost[current_tau] = cost_for_previous_tau[best_previous_tau_index]
         previous_change_point_index[current_tau] = previous_taus[best_previous_tau_index]
 
@@ -244,10 +242,12 @@ def ed_pelt(data: np.ndarray, min_distance: int = 1) -> np.ndarray:
 
     # here we collect the result list of changepoint indexes `change_point_indexes` using `previous_change_point_index`
     change_point_indexes: List[int] = []
-    current_index: int = previous_change_point_index[n]  # The index of the end of the last segment is `n`
+    current_index: np.int64 = np.int64(
+        previous_change_point_index[n]
+    )  # The index of the end of the last segment is `n`
     while current_index != 0:
         change_point_indexes.append(current_index)
-        current_index = previous_change_point_index[current_index]
+        current_index = np.int64(previous_change_point_index[current_index])
 
     # sort the change_point_indexes and transform it to a numpy ndarray
     result: np.ndarray = np.asarray(change_point_indexes, dtype=int)
