@@ -1,15 +1,12 @@
-# Copyright 2021 Cognite AS
+# Copyright 2023 Cognite AS
 from enum import Enum
 
 import numpy as np
 import pandas as pd
 
-from statsmodels.tsa.arima.model import ARIMA
-
 from indsl import versioning
-
-from ..exceptions import UserRuntimeError, UserValueError
-from ..type_check import check_types
+from indsl.exceptions import STATSMODELS_REQUIRED, UserRuntimeError, UserValueError
+from indsl.type_check import check_types
 
 
 class MethodType(Enum):
@@ -75,7 +72,6 @@ def arma_predictor(
 
     # If method is onestep, then iterate through test dataset and perform a one step prediction
     elif method == MethodType.ONESTEP:
-
         # Storage array
         store_forecast = []
 
@@ -83,7 +79,6 @@ def arma_predictor(
         cycles = min(n_obs - n_train, 100)
 
         for it in range(cycles + 1):
-
             # Append new observation
             train_data = data.iloc[it : it + n_train]
             res = _train_and_return_forecast(ar_order, ma_order, train_data, steps, dt_step_sec)
@@ -118,6 +113,11 @@ def _train_and_return_forecast(
     Returns:
         pandas.Series: Forecasted time series of length `steps`
     """
+    try:
+        from statsmodels.tsa.arima.model import ARIMA  # Lazy import
+    except ImportError:
+        raise ImportError(STATSMODELS_REQUIRED)
+
     # Fit ARMA model
     model = ARIMA(train_data, order=(ar_order, 0, ma_order))
     fit_model = model.fit()
