@@ -1,16 +1,14 @@
-# Copyright 2022 Cognite AS
-import typing
+# Copyright 2023 Cognite AS
+
+from typing import Literal
 
 import numpy as np
 import pandas as pd
 
-from statsmodels.tsa.holtwinters import ExponentialSmoothing
-
 from indsl import versioning
-
-from ..exceptions import UserRuntimeError, UserValueError
-from ..type_check import check_types
-from ..validations import validate_series_has_time_index
+from indsl.exceptions import STATSMODELS_REQUIRED, UserRuntimeError, UserValueError
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_time_index
 
 
 @versioning.register(version="1.0", deprecated=True)
@@ -18,8 +16,8 @@ from ..validations import validate_series_has_time_index
 def holt_winters_predictor(
     data: pd.Series,
     seasonal_periods: int,
-    seasonality: typing.Literal["add", "mul"] = "add",
-    trend: typing.Literal["add", "mul"] = "add",
+    seasonality: Literal["add", "mul"] = "add",
+    trend: Literal["add", "mul"] = "add",
     dampen_trend: bool = False,
     steps: int = 1,
     train_fraction: float = 0.8,
@@ -115,6 +113,11 @@ def _train_and_return_forecast(
     Returns:
         pandas.Series: Forecasted time series of length `steps`
     """
+    try:
+        from statsmodels.tsa.holtwinters import ExponentialSmoothing  # Lazy import
+    except ImportError:
+        raise ImportError(STATSMODELS_REQUIRED)
+
     fitted_model = ExponentialSmoothing(
         train_data,
         seasonal=seasonality,
