@@ -1,4 +1,4 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 from typing import Tuple
 
 import numpy as np
@@ -49,18 +49,18 @@ def calculate_gas_density(
     """
     # check specific gravity value
     validate_series_is_not_empty(sg)
-    sg = sg[0]
-    if sg == 0:
+    sg_ = sg[0]
+    if sg_ == 0:
         raise UserValueError("Specific gravity cannot be zero")
 
     # auto-align
     pressure, temperature = auto_align([pressure, temperature], align_timesteps)
 
-    M = M_AIR * sg  # Molar mass of gas
+    M = M_AIR * sg_  # Molar mass of gas
     R = R_U / M  # gas constant
 
     # calculate the pseudo - crtitical pressure and temperature
-    (Pc, Tc) = calculate_critical_prop(sg)
+    (Pc, Tc) = calculate_critical_prop(sg_)
 
     # convert pressure to kPa and temperature to K
     pressure_Kpa = CONVERT_PSI_TO_KPA * pressure
