@@ -1,10 +1,11 @@
+# Copyright 2023 Cognite AS
 from datetime import timedelta
 
 import numpy as np
 import pandas as pd
 
-from ..exceptions import UserValueError
-from ..type_check import check_types
+from indsl.exceptions import UserValueError
+from indsl.type_check import check_types
 
 
 @check_types
