@@ -1,15 +1,12 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
+
 from typing import Literal
 
 import numpy as np
 import pandas as pd
 
-from sklearn.linear_model import Lasso, LinearRegression, Ridge
-from sklearn.pipeline import make_pipeline
-from sklearn.preprocessing import PolynomialFeatures
-
-from ..exceptions import UserValueError
-from ..type_check import check_types
+from indsl.exceptions import SCIKIT_LEARN_REQUIRED, UserValueError
+from indsl.type_check import check_types
 
 
 @check_types
@@ -37,6 +34,13 @@ def poly_regression(
     Returns:
         pd.Series: Fitted data.
     """
+    try:
+        from sklearn.linear_model import Lasso, LinearRegression, Ridge
+        from sklearn.pipeline import make_pipeline
+        from sklearn.preprocessing import PolynomialFeatures
+    except ImportError:
+        raise ImportError(SCIKIT_LEARN_REQUIRED)
+
     # Check alpha
     if not 0 < alpha < 1:
         raise UserValueError("Alpha needs to be a float between 0 and 1")
