@@ -1,4 +1,4 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 import warnings
 
 from contextlib import suppress
@@ -9,10 +9,11 @@ import pandas as pd
 import scipy.interpolate
 
 from indsl import versioning
+from indsl.exceptions import UserValueError
 from indsl.ts_utils.ts_utils import functional_mean, is_na_all
+from indsl.type_check import check_types
+from indsl.warnings import IndslUserWarning
 
-from ..exceptions import UserValueError
-from ..type_check import check_types
 from . import interpolate_v1  # noqa
 
 
@@ -65,11 +66,11 @@ def interpolate(
     """
     # Check if all values are NaN
     if is_na_all(data):
-        warnings.warn("All values in the time series are NaN.", UserWarning)
+        warnings.warn("All values in the time series are NaN.", category=IndslUserWarning)
         return data
 
     # Allow for other ways of defining forward filling for stepwise functions
-    method = "previous" if method in ("ffill", "stepwise") else method  # type: ignore
+    method_ = "previous" if method in ("ffill", "stepwise") else method
 
     # Get outside fill value
     if bounded:
@@ -92,7 +93,7 @@ def interpolate(
 
     # Check for empty time series
     if len(observations) < 2:
-        warnings.warn("The time series contains less than two values.", UserWarning)
+        warnings.warn("The time series contains less than two values.", category=IndslUserWarning)
         return data
 
     # x and y datapoints used to construct linear piecewise function
@@ -101,7 +102,7 @@ def interpolate(
 
     # interpolator function
     interper = scipy.interpolate.interp1d(
-        x_observed, y_observed, kind=method, bounds_error=False, fill_value=fill_value
+        x_observed, y_observed, kind=method_, bounds_error=False, fill_value=fill_value
     )
 
     # If pointwise, sample directly from interpolated (or original) points
