@@ -1,10 +1,9 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 import pandas as pd
 
-from statsmodels.tsa.arima.model import ARIMA
-
-from ..type_check import check_types
-from ..validations import validate_series_is_not_empty
+from indsl.exceptions import STATSMODELS_REQUIRED
+from indsl.type_check import check_types
+from indsl.validations import validate_series_is_not_empty
 
 
 @check_types
@@ -26,7 +25,10 @@ def arma(data: pd.Series, ar_order: int = 2, ma_order: int = 2) -> pd.Series:
     Returns:
         pandas.Series: Smoothed data.
     """
-    # TODO: Refactor to accepet time window
+    try:
+        from statsmodels.tsa.arima.model import ARIMA
+    except ImportError:
+        raise ImportError(STATSMODELS_REQUIRED)
 
     validate_series_is_not_empty(data)
 
