@@ -1,12 +1,11 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 from typing import Optional
 
 import numpy as np
 import pandas as pd
 
-from numba import jit
-
 from indsl import versioning
+from indsl.decorators import jit
 from indsl.type_check import check_types
 
 from . import lweight_ma_v1  # noqa
