@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2023 Cognite AS
 import pandas as pd
 
 from indsl import versioning
@@ -26,6 +26,6 @@ def sma(data: pd.Series, time_window: str = "60min", min_periods: int = 1) -> pd
     Returns:
         pandas.Series: Smoothed time series
     """
-    time_window = time_parse(time_window, sma.__name__)
+    time_window_ = time_parse(time_window, sma.__name__)
 
-    return data.rolling(time_window, min_periods=min_periods).mean()
+    return data.rolling(time_window_, min_periods=min_periods).mean()
