@@ -1,4 +1,4 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 import re
 import warnings
 
@@ -9,9 +9,9 @@ import numpy as np
 import pandas as pd
 import scipy.integrate
 
+from indsl.exceptions import UserRuntimeError, UserValueError
 from indsl.type_check import check_types
-
-from ..exceptions import UserRuntimeError, UserValueError
+from indsl.warnings import IndslUserWarning
 
 
 _unit_in_ms_without_week = {"s": 1000, "m": 60000, "h": 3600000, "d": 86400000}
@@ -40,9 +40,7 @@ def granularity_to_ms(granularity: str) -> int:
     ms = time_string_to_ms(r"(\d+)({})", granularity, _unit_in_ms_without_week)
     if ms is None:
         raise UserValueError(
-            "Invalid granularity format: `{}`. Must be on format <integer>(s|m|h|d). E.g. '5m', '3h' or '1d'.".format(
-                granularity
-            )
+            f"Invalid granularity format: `{granularity}`. Must be on format <integer>(s|m|h|d). E.g. '5m', '3h' or '1d'."
         )
     return ms
 
@@ -54,9 +52,7 @@ def time_ago_to_ms(time_ago_string: str) -> int:
     ms = time_string_to_ms(r"(\d+)({})-ago", time_ago_string, _unit_in_ms)
     if ms is None:
         raise UserValueError(
-            "Invalid time-ago format: `{}`. Must be on format <integer>(s|m|h|d|w)-ago or 'now'. E.g. '3d-ago' or '1w-ago'.".format(
-                time_ago_string
-            )
+            f"Invalid time-ago format: `{time_ago_string}`. Must be on format <integer>(s|m|h|d|w)-ago or 'now'. E.g. '3d-ago' or '1w-ago'."
         )
     return ms
 
@@ -203,7 +199,7 @@ def gaps_detector(timestamps: np.ndarray, threshold: int = 86400) -> np.ndarray:
     return gaps
 
 
-def time_difference(data: pd.Series, unit: str = "ms") -> pd.Series:
+def time_difference(data: pd.Series) -> pd.Series:
     """Calculate the time difference between two consecutive points.
 
     Args:
@@ -214,13 +210,14 @@ def time_difference(data: pd.Series, unit: str = "ms") -> pd.Series:
         pd.Series: Time difference between two consecutive points.
 
     """
-    return data.index.to_series().diff().dropna().astype(dtype=f"timedelta64[{unit}]")
+    timedelta_series = data.index.astype("datetime64[ns]").to_series().diff().dropna()
+    return timedelta_series.dt.total_seconds() * 1000  # ms
 
 
 @check_types
 def mad(
     data: pd.Series,
-) -> float:
+) -> Union[float, int, pd.Timedelta]:
     """Median absolute deviation (MAD).
 
     Median absolute deviation computed for a time series.
@@ -252,13 +249,14 @@ def check_uniform(data: pd.DataFrame, unit: str = "ns") -> bool:
     return np.all(floored[0] == floored[1:])
 
 
-def make_uniform(data: pd.DataFrame, resolution: str = "1s", interpolation: str = None) -> pd.DataFrame:
+def make_uniform(data: pd.DataFrame, resolution: str = "1s", interpolation: Optional[str] = None) -> pd.DataFrame:
     """Make time series uniform.
 
     Convenience method to make an input time series dataframe uniform per specified temporal resolution.
     Object must have a datetime-like index.
 
     Args:
+        data: Input time series dataframe.
         resolution: Temporal resolution of uniform time series. Follows Pandas DateTime convention. Defaults to "1s".
         interpolation: Method for optional interpolation. Follows pandas Resampler.interpolate. Defaults to None.
 
@@ -291,8 +289,8 @@ def time_parse(time_window: str = "60min", function_name: str = "") -> pd.Timede
     """
     if str.isdigit(time_window):  # if user gives '60' it will be considered as '60min'
         warnings.warn(
-            f"Missing time unit in argument 'time_window' in {function_name} function, assuming {time_window}min.",
-            UserWarning,
+            f"Missing time unit in argument 'time_window' in {function_name} function, assuming {time_window} min.",
+            category=IndslUserWarning,
         )
         time_window = str(time_window) + "min"
     try:
@@ -355,13 +353,13 @@ def fill_gaps(
     if granularity is None:
         # If granularity is not given as input. Granularity will be inferred from the data
         granularity = pd.Timedelta(data.index.inferred_freq)
-    if granularity == pd.Timedelta("0T"):
+    if granularity == pd.Timedelta("0min"):
         raise UserValueError("granularity can not be 0")
 
-    if ffill_resolution == pd.Timedelta("0T"):
+    if ffill_resolution == pd.Timedelta("0min"):
         raise UserValueError("ffill_resolution can not be 0")
 
-    if interpolate_resolution == pd.Timedelta("0T"):
+    if interpolate_resolution == pd.Timedelta("0min"):
         raise UserValueError("interpolate_resolution can not be 0")
 
     small_gap = 0
@@ -392,7 +390,12 @@ def fill_gaps(
     mask = np.logical_and(nan_group_size > small_gap, nan_group_size <= mask_gap)
     data[mask] = data.interpolate(method="linear", limit_direction="forward", limit=inter_gap)
 
-    return data.fillna(method=method)
+    if method in ["ffill", "pad"]:
+        return data.ffill()
+    elif method in ["backfill", "bfill"]:
+        return data.bfill()
+    else:
+        raise UserValueError(f"Method {method} is not supported. Use 'ffill', 'backfill', 'bfill' or 'pad'.")
 
 
 def number_of_events(out: pd.Series):
@@ -411,7 +414,5 @@ def scalar_to_pandas_series(data: Union[float, pd.Series]) -> pd.Series:
         pd.Series: Data as series.
     """
     if isinstance(data, float):
-        # IDEA: Use const_value function instead, but have to avoid circular import
-        # Needs at least two values covering the whole time span of interest to work with auto_align
         data = pd.Series(data, index=pd.date_range(start="1970", end=pd.Timestamp.now(), periods=2))
     return data
