@@ -1,4 +1,4 @@
-# Copyright 2022 Cognite AS
+# Copyright 2023 Cognite AS
 
 from datetime import datetime, timedelta
 from typing import List, Literal, Optional, Tuple, Union
@@ -8,13 +8,12 @@ import pandas as pd
 
 from scipy.stats import shapiro
 
+from indsl.exceptions import UserTypeError, UserValueError
 from indsl.resample.auto_align import auto_align
-
-from ..exceptions import UserValueError
-from ..type_check import check_types
+from indsl.type_check import check_types
 
 
-TimeUnits = Literal["ns", "us", "ms", "s", "m", "h", "D", "W"]
+TimeUnits = Literal["ns", "us", "ms", "s", "m", "h", "d", "W"]
 
 
 # Rounding and utility functions
@@ -32,7 +31,7 @@ def round(x, decimals: int):
         pd.Series: time series
 
     """
-    return np.round_(x, decimals=decimals)
+    return np.round(x, decimals=decimals)
 
 
 def floor(x):
@@ -193,7 +192,7 @@ def set_timestamps(timestamp_series: pd.Series, value_series: pd.Series, unit: T
         timestamp_series: Timestamp time series
         value_series: Value time series
         unit: Timestamp unit
-          Valid values "ns|us|ms|s|m|h|D|W". Default "ms"
+          Valid values "ns|us|ms|s|m|h|d|W". Default "ms"
 
     Returns:
         pd.Series: time series
@@ -222,7 +221,7 @@ def get_timestamps(series: pd.Series, unit: TimeUnits = "ms") -> pd.Series:
     Args:
         series: Time-series
         unit: Timestamp unit
-          Valid values "ns|us|ms|s|m|h|D|W". Default "ms"
+          Valid values "ns|us|ms|s|m|h|d|W". Default "ms"
 
     Returns:
         pd.Series: time series
@@ -250,7 +249,7 @@ def time_shift(series: pd.Series, n_units: float = 0, unit: TimeUnits = "ms") ->
         n_units: Time periods to shift
             Number of time periods to shift
         unit: Time period unit
-          Valid values "ns|us|ms|s|m|h|D|W". Default "ms"
+          Valid values "ns|us|ms|s|m|h|d|W". Default "ms"
 
     Returns:
         pd.Series: time series
@@ -279,8 +278,8 @@ def replace(series: pd.Series, to_replace: Optional[List[float]] = None, value:
         to_replace: Replace
             List of values to replace. The values must be seperated by semicolons. Infinity and undefined values can be
             replaced by using the keywords inf, -inf and nan. The default is to replace no values.
-        value: By
-            Value used as replacement. Default is 0.0
+        value: Value used as replacement.
+            Default is 0.0
 
     Returns:
         pd.Series: time series
@@ -293,6 +292,10 @@ def replace(series: pd.Series, to_replace: Optional[List[float]] = None, value:
     """
     if to_replace is None:
         return series
+    elif not isinstance(to_replace, list):
+        raise UserTypeError("to_replace must be a list")
+    if value is not None and not isinstance(value, (float, int)):
+        raise UserTypeError("value must be a number")
     return series.replace(to_replace, value)
 
 
@@ -315,7 +318,7 @@ def remove(
         range_from: Range start
             Only values above this parameter will be kept. If empty, which is the default, this range filter is deactivated.
         range_to: Range end
-            Only values above this parameter will be kept. If empty, which is the default, the range filter is deactivated.
+            Only values below this parameter will be kept. If empty, which is the default, the range filter is deactivated.
 
     Returns:
         pd.Series: time series
@@ -324,6 +327,8 @@ def remove(
         UserTypeError: series is not a time series
         UserTypeError: to_remove is not a list
     """
+    if to_remove is not None and not isinstance(to_remove, list):
+        raise UserTypeError("to_replace must be a list")
     if to_remove is not None:
         series = series[~series.isin(to_remove)]
     if range_from is not None:
@@ -383,7 +388,7 @@ def generate_step_series(flag: pd.Series) -> pd.Series:
                          0               01      1
     """
     # add first point as the start of the step time series
-    step_time_series = pd.Series([flag[0]], index=[flag.index[0]])
+    step_time_series = pd.Series([flag.iloc[0]], index=[flag.index[0]])
 
     # compute actual_value - previous_value
     flag_shift = flag.diff(1)
@@ -421,7 +426,7 @@ def generate_step_series(flag: pd.Series) -> pd.Series:
 
     # add last point if it doesn't exist
     if flag.index[-1] != step_time_series.index[-1]:
-        step_time_series = pd.concat([step_time_series, pd.Series(flag[-1], index=[flag.index[-1]])])
+        step_time_series = pd.concat([step_time_series, pd.Series(flag.iloc[-1], index=[flag.index[-1]])])
 
     # remove the last point if the number of 1 values is odd
     if len(step_time_series[step_time_series == 1]) % 2 != 0:
@@ -451,8 +456,8 @@ def create_series_from_timesteps(timesteps: List[timedelta]) -> pd.Series:
 
 
 def normality_assumption_test(
-    series: Union[pd.Series, np.array], max_data_points: int = 5000, min_p_value: float = 0.05, min_W: float = 0.5
-) -> Tuple[float, float]:
+    series: Union[pd.Series, np.ndarray], max_data_points: int = 5000, min_p_value: float = 0.05, min_W: float = 0.5
+) -> Optional[Tuple[float, float]]:
     """Test for normality assumption.
 
     This function performs a Shapiro-Wilk test to check if the data is normally distributed.
@@ -477,18 +482,18 @@ def normality_assumption_test(
     """
     if len(series) > max_data_points:
         raise UserValueError(f"This time series exceeds the limit of {max_data_points} datapoints to perform the test.")
+    if len(series) < 3:
+        raise UserValueError("Time series must contain at least 3 data points.")
 
     W, p_value = shapiro(series)
 
-    if p_value == 1.0 and W == 1.0:
-        raise UserValueError("This time series is uniform and not normally distributed")
     if p_value < min_p_value or W < min_W:
         raise UserValueError("This time series is not normally distributed")
 
-    return  # type: ignore
+    return None
 
 
-def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater") -> np.array:
+def z_scores_test(x: np.ndarray, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater") -> np.ndarray:
     """Z-scores test.
 
     This functions performs a z-scores test given a cut-off value and returns a binary time series.
@@ -499,11 +504,11 @@ def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater"
             Number of standard deviations from the mean.
         direction: Direction of the test.
             Options:
-                "greater": the function will check if the z-scores are greater than the cut-off
-                "less": the function will check if the z-scores are less than the cut-off
+            - "greater": the function will check if the z-scores are greater than the cut-off
+            - "less": the function will check if the z-scores are less than the cut-off
 
     Returns:
-         np.array: Binary np.array with the results of the test.
+        np.ndarray: Binary np.array with the results of the test.
             1 values indicate that the test has passed.
     """
     if (std := x.std()) == 0.0:
@@ -515,8 +520,8 @@ def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater"
 
 
 def modified_z_scores_test(
-    x: np.array, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater"
-) -> np.array:
+    x: np.ndarray, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater"
+) -> np.ndarray:
     """Z-scores test.
 
     This functions performs a modified z-scores test given a cut-off value and returns a binary time series.
@@ -526,12 +531,12 @@ def modified_z_scores_test(
         cutoff: Cut-off value.
         direction: Direction of the test.
             Options:
-                "greater": the function will check if the modified z-scores are greater than the cut-off
-                "less": the function will check if the modified z-scores are less than the cut-off
+            - "greater": the function will check if the modified z-scores are greater than the cut-off
+            - "less": the function will check if the modified z-scores are less than the cut-off
 
     Returns:
-         np.array: Binary np.array with the results of the test.
-            1 values indicate that the test has passed.
+        np.ndarray: Binary np.array with the results of the test.
+                    1 values indicate that the test has passed.
     """
     median = np.median(x)
     if (mad := np.median(np.abs(x - median))) == 0.0:
@@ -543,8 +548,8 @@ def modified_z_scores_test(
 
 
 def iqr_test(
-    x: np.array, limit: Literal["upper", "lower"] = "upper", direction: Literal["greater", "less"] = "greater"
-) -> np.array:
+    x: np.ndarray, limit: Literal["upper", "lower"] = "upper", direction: Literal["greater", "less"] = "greater"
+) -> np.ndarray:
     """Z-scores test.
 
     This functions performs a iqr test and returns a binary time series.
@@ -554,12 +559,12 @@ def iqr_test(
         limit: Cut-off limit.
         direction: Direction of the test.
             Options:
-                "greater": the function will check if the values are greater than the cut-off limit.
-                "less": the function will check if the values are less than the cut-off limit.
+            - "greater": the function will check if the values are greater than the cut-off limit.
+            - "less": the function will check if the values are less than the cut-off limit.
 
     Returns:
-         np.array: Binary np.array with the results of the test.
-            1 values indicate that the test has passed.
+        np.ndarray: Binary np.array with the results of the test.
+                    1 values indicate that the test has passed.
     """
     percentile25 = np.quantile(x, 0.25)
     percentile75 = np.quantile(x, 0.75)
@@ -573,7 +578,7 @@ def iqr_test(
     return threshold_test(x, cutoff, direction)
 
 
-def threshold_test(x: np.array, cutoff: float, direction: Literal["greater", "less"]) -> np.array:
+def threshold_test(x: np.ndarray, cutoff: float, direction: Literal["greater", "less"]) -> np.ndarray:
     """Threshold test.
 
     This functions performs a threshold test based on a direction (greater than or less than).
@@ -583,12 +588,12 @@ def threshold_test(x: np.array, cutoff: float, direction: Literal["greater", "le
         cutoff: Cut-off value.
         direction: Direction of the test.
             Options:
-                "greater": the function will check if the values are greater than the cut-off limit.
-                "less": the function will check if the values are less than the cut-off limit.
+            - "greater": the function will check if the values are greater than the cut-off limit.
+            - "less": the function will check if the values are less than the cut-off limit.
 
     Returns:
-         np.array: Binary np.array with the results of the test.
-            1 values indicate that the test has passed.
+        np.ndarray: Binary np.array with the results of the test.
+                    1 values indicate that the test has passed.
     """
     if direction == "greater":
         return np.where(x > cutoff, 1, 0)
